Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FilePathsGetter ¶
FilePathsGetter takes a filepath and returns filenpaths in a slice
type FilesComponents ¶
type FilesComponents struct {
FilePathsGetter
Imager
Resizer
Writer
}
FilesComponents are all the interfaces wich are needed for resizing files
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
cli
command
|
|
|
Package jpg implements the jpg2go Imager interface by using the jpg package from the standart lilbrary
|
Package jpg implements the jpg2go Imager interface by using the jpg package from the standart lilbrary |
|
Package nfntresizer implements the Resizer by using the Resizer package from nfnt
|
Package nfntresizer implements the Resizer by using the Resizer package from nfnt |
|
Package osfiles is an implementation for the FilePathGetter and the Writer interface.
|
Package osfiles is an implementation for the FilePathGetter and the Writer interface. |
|
Package resize uses the jpg2go interfaces to resize alle the pictures
|
Package resize uses the jpg2go interfaces to resize alle the pictures |
Click to show internal directories.
Click to hide internal directories.